%
% Synthetic Reservoir model and pore pressure
% synthetic input generator for 
% 'pemodel.x' and 'zpemodel.x' 0.5
%
% Matlab script for automatic SEP147
% report generation
%
% 2012 Musa Maharramov
% Stanford Exploration Project
% Stanford University
%
clc
%
% set output file names
% make sure 'Data', 'Par' and 'Out' directories 
% exist in the parent folder
DATDIR='Data/';
PARDIR='Par/';
OUTDIR='Out/';
% binary files for undrained bulk modulus
% mineral grain bulk modulus, shear modulus
% and Poisson's ratio
ksatfile=[DATDIR 'ksat.bin'];
kminfile=[DATDIR 'kmin.bin'];
shearfile=[DATDIR 'shear.bin'];
poissonfile=[DATDIR 'poisson.bin'];
%
% reservoir bottom surface - three resolutions
bottomsurffilel=[DATDIR 'rzhilowres.bin'];
bottomsurffilem=[DATDIR 'rzhimidres.bin'];
bottomsurffileh=[DATDIR 'rzhihires.bin'];
%
% reservoir top surface - three resolutions
topsurffilel=[DATDIR 'rzlolowres.bin'];
topsurffilem=[DATDIR 'rzlomidres.bin'];
topsurffileh=[DATDIR 'rzlohires.bin'];
%
% axisymmetric pressure drop - three resolutions
axisymppfilel=[DATDIR 'ppsymlowres.bin'];
axisymppfilem=[DATDIR 'ppsymmidres.bin'];
axisymppfileh=[DATDIR 'ppsymhires.bin'];
%
% asymmetric pressure drop - three resolutions
asymppfilel=[DATDIR 'ppasymlowres.bin'];
asymppfilem=[DATDIR 'ppasymmidres.bin'];
asymppfileh=[DATDIR 'ppasymhires.bin'];
%
% LACQ synthetic reservoir header - three resolutions
lacqheaderfilel=[DATDIR 'lacqlowres.hdr'];
lacqheaderfilem=[DATDIR 'lacqmidres.hdr'];
lacqheaderfileh=[DATDIR 'lacqhires.hdr'];
%
% model limited to the surface only
Llacqheaderfilel=[DATDIR 'Llacqlowres.hdr'];
Llacqheaderfilem=[DATDIR 'Llacqmidres.hdr'];
Llacqheaderfileh=[DATDIR 'Llacqhires.hdr'];
%
% binary file names for depth-variable
% moduli and header files for 3 resolutions
depthksatfile=[DATDIR 'depthksat.bin'];
depthkminfile=[DATDIR 'depthkmin.bin'];
depthshearfile=[DATDIR 'depthshear.bin'];
depthpoissonfile=[DATDIR 'depthpoisson.bin'];
lacqheaderfileld=[DATDIR 'lacqlowresdepth.hdr'];
lacqheaderfilemd=[DATDIR 'lacqmidresdepth.hdr'];
lacqheaderfilehd=[DATDIR 'lacqhiresdepth.hdr'];
%
% simulated LACQ subsidence data
lacqsubsidencefile=[DATDIR 'lacqsimulated.bin'];
%
% parameter file names
parmodelsyml=[PARDIR 'par_model_symlowres'];
parmodelsymm=[PARDIR 'par_model_symmidres'];
parmodelsymh=[PARDIR 'par_model_symhires'];
%
parmodelasyml=[PARDIR 'par_model_asymlowres'];
parmodelasymm=[PARDIR 'par_model_asymmidres'];
parmodelasymh=[PARDIR 'par_model_asymhires'];
%
% inversion parameter files
parinvertsyml=[PARDIR 'par_invert_symlowres'];
parinvertsymm=[PARDIR 'par_invert_symmidres'];
parinvertsymh=[PARDIR 'par_invert_symhires'];
%
parinvertasyml=[PARDIR 'par_invert_asymlowres'];
parinvertasymm=[PARDIR 'par_invert_asymmidres'];
parinvertasymh=[PARDIR 'par_invert_asymhires'];
%
parinvertlacql=[PARDIR 'par_invert_lacqlowres'];
parinvertlacqm=[PARDIR 'par_invert_lacqmidres'];
parinvertlacqh=[PARDIR 'par_invert_lacqhires'];
%
% modelling param files for depth-variable models
parmodelsymld=[PARDIR 'zpar_model_symlowres'];
parmodelsymmd=[PARDIR 'zpar_model_symmidres'];
parmodelsymhd=[PARDIR 'zpar_model_symhires'];
%
parmodelasymld=[PARDIR 'zpar_model_asymlowres'];
parmodelasymmd=[PARDIR 'zpar_model_asymmidres'];
parmodelasymhd=[PARDIR 'zpar_model_asymhires'];
%
% output binary names
dispoutsyml=[OUTDIR 'dispoutsymlowres.bin'];
poreoutsyml=[OUTDIR 'poreoutsymlowres.bin'];
dispoutsymm=[OUTDIR 'dispoutsymmidres.bin'];
poreoutsymm=[OUTDIR 'poreoutsymmidres.bin'];
dispoutsymh=[OUTDIR 'dispoutsymhires.bin'];
poreoutsymh=[OUTDIR 'poreoutsymhires.bin'];
dispoutasyml=[OUTDIR 'dispoutasymlowres.bin'];
poreoutasyml=[OUTDIR 'poreoutasymlowres.bin'];
dispoutasymm=[OUTDIR 'dispoutasymmidres.bin'];
poreoutasymm=[OUTDIR 'poreoutasymmidres.bin'];
dispoutasymh=[OUTDIR 'dispoutasymhires.bin'];
poreoutasymh=[OUTDIR 'poreoutasymhires.bin'];
dispoutsymld=[OUTDIR 'zdispoutsymlowres.bin'];
poreoutsymld=[OUTDIR 'zporeoutsymlowres.bin'];
dispoutsymmd=[OUTDIR 'zdispoutsymmidres.bin'];
poreoutsymmd=[OUTDIR 'zporeoutsymmidres.bin'];
dispoutsymhd=[OUTDIR 'zdispoutsymhires.bin'];
poreoutsymhd=[OUTDIR 'zporeoutsymhires.bin'];
dispoutasymld=[OUTDIR 'zdispoutasymlowres.bin'];
poreoutasymld=[OUTDIR 'zporeoutasymlowres.bin'];
dispoutasymmd=[OUTDIR 'zdispoutasymmidres.bin'];
poreoutasymmd=[OUTDIR 'zporeoutasymmidres.bin'];
dispoutasymhd=[OUTDIR 'zdispoutasymhires.bin'];
poreoutasymhd=[OUTDIR 'zporeoutasymhires.bin'];
%
% inversion of LACQ data
poreoutlacql=[OUTDIR 'Lporeoutlacqlowres.bin'];
dispoutlacql=[OUTDIR 'dispoutlacqlowres.bin'];
poreoutlacqm=[OUTDIR 'Lporeoutlacqmidres.bin'];
dispoutlacqm=[OUTDIR 'dispoutlacqmidres.bin'];
poreoutlacqh=[OUTDIR 'Lporeoutlacqhires.bin'];
dispoutlacqh=[OUTDIR 'dispoutlacqhires.bin'];
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% all distances in km, moduli in GPa,
% pressures in MPa
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% RESERVOIR PARAMETERS
%
% reservoir radius
RADIUS_RES=8.;
% amplitude of the reservoir dome
AMPL_RES=1.4;
% characteristic length of structure
CHRCT_LENGTH=5.;
% depth of the reservoir
DEPTH_RES=3.5;
% max pressure drop (MPa)
PP_MAX=55.;
% reservoir width
WIDTH_RES=.35;
% shifted max pressure drop peak for
% asymmetric modelling
SHIFTED_X0=3.;SHIFTED_Y0=3.;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% ELASTIC MODEL PARAMETERS
%
% shear modulus at nz
SHEAR_MODULUS=23.;
% shear hyperbolic scaling factor
SHEAR_DEPTH_SCALE=2.;
%
% we only care about ksat/kmin for 
% teh Biot coefficient,
% so the value of the undrained
% and mineral moduli are relative
K_UNDRAINED=.75;
K_MINERAL=1.;
%
% poisson ratio at nz
POISSON_RATIO=.25;
% Poisson's ratio hyperbolic scaling factor
POISSON_DEPTH_SCALE=1.;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% MODEL GRID
%
nx=101;ny=101;nz=5;nzz=20;
x0=-10.;y0=-10.;z0=0;
dx=-2.*x0/(nx-1);dy=-2.*y0/(ny-1);dz=.1;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LOW-RESOLUTION RESERVOIR GRID
%
rnxl=11;rnyl=11;
rx0=-RADIUS_RES;ry0=-RADIUS_RES;
rdxl=2.*RADIUS_RES/(rnxl-1);rdyl=2.*RADIUS_RES/(rnyl-1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% MEDIUM-RESOLUTION RESERVOIR GRID
%
rnxm=41;rnym=41;
rdxm=2.*RADIUS_RES/(rnxm-1);rdym=2.*RADIUS_RES/(rnym-1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% HIGH-RESOLUTION RESERVOIR GRID
%
rnxh=81;rnyh=81;
rdxh=2.*RADIUS_RES/(rnxh-1);rdyh=2.*RADIUS_RES/(rnyh-1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% OMP
%
NOMP=8;
%
% max inversion iterations
%
MAX_ITER=15;
%
% solver tolerance parameter for inversion
% iterations on the denser grid
DENSE_TOL=1.e-4;
%
%  END OF PARAMETGER DEFINITION
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% SYNTHETIC GENERATION
%
% Extrapolate 1D data from Segall et.al
% to a full 3D subsidence profile.
%
% Paul Segall, Jean-Robert Grasso, and Antony
% Mossop. Poroelastic stressing and induced
% seismicity near the Lacq gas field, 
% southwestern France. Journal of Geophysics
% Research, 99:15423–15438, 1994.
% http://dx.doi.org/10.1029/94JB00989.
%
% SE subsidence profile (m)
se_subs = [58 53 30 0 0]/1000;
% SE dist (km)
se_dist = [0 3 4 9 13];
% NW subsidence profile (m)
nw_subs = [58 23 20 19 0]/1000;
% NW dist (km)
nw_dist = [0 4  6 10 13];
%
NRP=500;
dense_radii=linspace(0.,13.,NRP);
%
se_profile=interp1(se_dist,se_subs,dense_radii,'linear');
nw_profile=interp1(se_dist,nw_subs,dense_radii,'linear');
%
% presumed lacq subsidence in polar coordinates  
dense_phi=linspace(0.,2*pi,NRP);
lacq_subs_polar=zeros(NRP,NRP);
for iphi=1:NRP
  phi=(iphi-1)*2*pi/NRP;
  for irho=1:NRP    
    lacq_subs_polar(irho,iphi)=nw_profile(irho)+...
         (se_profile(irho)-nw_profile(irho))*sin((phi+pi/4)/2.)^2;
  end
end
% convert to cartesian
lacq_real=zeros(3*nx,ny);
for iy=1:ny
  y=dy*(iy-1)+y0;
  for ix=1:nx
    x=dx*(ix-1)+x0;
    iphi=min(floor((atan2(y,x)+pi)/(2.*pi/NRP))+1,NRP);
    irho=min(floor(((x^2+y^2)^.5)/(13./NRP))+1,NRP);
    lacq_real(3*ix-2:3*ix-1,iy)=0;
    lacq_real(3*ix,iy)=lacq_subs_polar(irho,iphi);
  end
end
%
% write simulated 'real' subsidence data to binary file
%
hfile=fopen(['../' lacqsubsidencefile],'w','ieee-le');
fwrite(hfile,lacq_real,'float');
fclose(hfile);
% 
% reservoir bounding surfaces
rzlo=zeros(rnxl,rnyl);
rzhi=zeros(rnxl,rnyl);
% specified pore pressure drop
pp=zeros(rnxl,rnyl);
ppasym=pp;
%
% low-res reservoir grid
for iy=1:rnyl
  for ix=1:rnxl    
    rho=((rx0+(ix-1)*rdxl)^2+...
        (ry0+(iy-1)*rdyl)^2)^.5;
    rho2=((rx0+(ix-1)*rdxl-SHIFTED_X0)^2+...
        (ry0+(iy-1)*rdyl-SHIFTED_Y0)^2)^.5;
    rzlo(ix,iy)=DEPTH_RES-AMPL_RES*(exp(-(rho/CHRCT_LENGTH)^2)-.5);
    rzhi(ix,iy)=rzlo(ix,iy)+WIDTH_RES;
    pp(ix,iy)=PP_MAX*exp(-(rho/...
        RADIUS_RES)^4);
    ppasym(ix,iy)=PP_MAX*exp(-(rho2/...
        (RADIUS_RES+(sin(atan2(ry0+(iy-1)*rdyl-SHIFTED_Y0,...
        rx0+(ix-1)*rdxl-SHIFTED_X0)-pi/4)^2)*RADIUS_RES/3))^4);
% make the reservois circular        
    if (rho > RADIUS_RES)
      rzhi(ix,iy)=rzlo(ix,iy);
    end    
  end
end
%
% ditto for mid-res reservoir grid
rzlom=zeros(rnxm,rnym);
rzhim=zeros(rnxm,rnym);
% specified pore pressure drop
ppm=zeros(rnxm,rnym);
ppasymm=ppm;
for iy=1:rnym
  for ix=1:rnxm
    rho=((rx0+(ix-1)*rdxm)^2+...
        (ry0+(iy-1)*rdym)^2)^.5;
    rho2=((rx0+(ix-1)*rdxm-SHIFTED_X0)^2+...
        (ry0+(iy-1)*rdym-SHIFTED_Y0)^2)^.5;
    rzlom(ix,iy)=DEPTH_RES-AMPL_RES*(exp(-(rho/CHRCT_LENGTH)^2)-.5);
    rzhim(ix,iy)=rzlom(ix,iy)+WIDTH_RES;
    ppm(ix,iy)=PP_MAX*exp(-(rho/...
        RADIUS_RES)^4);
    ppasymm(ix,iy)=PP_MAX*exp(-(rho2/...
        (RADIUS_RES+(sin(atan2(ry0+(iy-1)*rdym-SHIFTED_Y0,...
        rx0+(ix-1)*rdxm-SHIFTED_X0)-pi/4)^2)*RADIUS_RES/3))^4);
% make the reservois circular        
    if (rho > RADIUS_RES)
      rzhim(ix,iy)=rzlom(ix,iy)-0.1;
    end    
  end
end
%
% ditto for hi-res reservoir grid
rzloh=zeros(rnxh,rnyh);
rzhih=zeros(rnxh,rnyh);
% specified pore pressure drop
pph=zeros(rnxh,rnyh);
ppasymh=pph;
for iy=1:rnyh
  for ix=1:rnxh
    rho=((rx0+(ix-1)*rdxh)^2+...
        (ry0+(iy-1)*rdyh)^2)^.5;
    rho2=((rx0+(ix-1)*rdxh-SHIFTED_X0)^2+...
        (ry0+(iy-1)*rdyh-SHIFTED_Y0)^2)^.5;
    rzloh(ix,iy)=DEPTH_RES-AMPL_RES*(exp(-(rho/CHRCT_LENGTH)^2)-.5);
    rzhih(ix,iy)=rzloh(ix,iy)+WIDTH_RES;
    pph(ix,iy)=PP_MAX*exp(-(rho/...
        RADIUS_RES)^4);
    ppasymh(ix,iy)=PP_MAX*exp(-(rho2/...
        (RADIUS_RES+(sin(atan2(ry0+(iy-1)*rdyh-SHIFTED_Y0,...
        rx0+(ix-1)*rdxh-SHIFTED_X0)-pi/4)^2)*RADIUS_RES/3))^4);
% make the reservois circular        
    if (rho > RADIUS_RES)
      rzhih(ix,iy)=rzloh(ix,iy)-0.1;
    end    
  end
end
%
% write reservoir bounding surfaces 
% to binary files
hfile=fopen(['../' topsurffilel],'w','ieee-le');
fwrite(hfile,rzlo,'float');
fclose(hfile);
hfile=fopen(['../' bottomsurffilel],'w','ieee-le');
fwrite(hfile,rzhi,'float');
fclose(hfile);
% ditto for mid-res
hfile=fopen(['../' topsurffilem],'w','ieee-le');
fwrite(hfile,rzlom,'float');
fclose(hfile);
hfile=fopen(['../' bottomsurffilem],'w','ieee-le');
fwrite(hfile,rzhim,'float');
fclose(hfile);
% ditto for high-res
hfile=fopen(['../' topsurffileh],'w','ieee-le');
fwrite(hfile,rzloh,'float');
fclose(hfile);
hfile=fopen(['../' bottomsurffileh],'w','ieee-le');
fwrite(hfile,rzhih,'float');
fclose(hfile);
%
% write synthetic pore pressures
% to binary files
%
hfile=fopen(['../' axisymppfilel],'w','ieee-le');
fwrite(hfile,pp,'float');
fclose(hfile);
hfile=fopen(['../' asymppfilel],'w','ieee-le');
fwrite(hfile,ppasym,'float');
fclose(hfile);
% ditto for mid-res
hfile=fopen(['../' axisymppfilem],'w','ieee-le');
fwrite(hfile,ppm,'float');
fclose(hfile);
hfile=fopen(['../' asymppfilem],'w','ieee-le');
fwrite(hfile,ppasymm,'float');
fclose(hfile);
% ditto for high-res
hfile=fopen(['../' axisymppfileh],'w','ieee-le');
fwrite(hfile,pph,'float');
fclose(hfile);
hfile=fopen(['../' asymppfileh],'w','ieee-le');
fwrite(hfile,ppasymh,'float');
fclose(hfile);
%
% init poroelastic medium parameters
% and write to binary files
%
% undrained bulk modulus
model=K_UNDRAINED*ones(nz,nx,ny); 
hfile=fopen(['../' ksatfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% depth-variable undrained bulk modulus
model=K_UNDRAINED*ones(nzz,nx,ny); 
hfile=fopen(['../' depthksatfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% mineral grain bulk modulus
model=K_MINERAL*ones(nz,nx,ny);
hfile=fopen(['../' kminfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% depth-variable mineral grain bulk modulus
model=K_MINERAL*ones(nzz,nx,ny);
hfile=fopen(['../' depthkminfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% shear modulus (in GPa)
model=SHEAR_MODULUS*ones(nz,nx,ny);
hfile=fopen(['../' shearfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% depth-variable shear modulus -
% hyperbolic scaling with the depth
model=SHEAR_MODULUS*ones(nzz,nx,ny);
for iz=1:nzz
  model(iz,:,:)=model(iz,:,:)*1./...
      (1.+(SHEAR_DEPTH_SCALE-1.)*(nzz-iz)/max(nz-1,1));
end
hfile=fopen(['../' depthshearfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% Poisson's ratio
model=POISSON_RATIO*ones(nz,nx,ny);
hfile=fopen(['../' poissonfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% depth-variable Poisson's ratio -
% hyperbolic scaling with the depth
model=POISSON_RATIO*ones(nzz,nx,ny);
for iz=1:nzz
  model(iz,:,:)=model(iz,:,:)*1./...
      (1.+(POISSON_DEPTH_SCALE-1.)*(nzz-iz)/max(nz-1,1));
end
hfile=fopen(['../' depthpoissonfile],'w','ieee-le');
fwrite(hfile,model,'float');
fclose(hfile);
%
% create reservoir header 
% readable by expt_tk_0.5
% Fortran 2003 Object-oriented
% Framework
%
hfile=fopen(['../' lacqheaderfilel],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxl);
fprintf(hfile,'rny=%d\n', rnyl);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxl);
fprintf(hfile,'rdy=%f\n', rdyl);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilel);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilel);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
% ditto for mid-res
hfile=fopen(['../' lacqheaderfilem],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxm);
fprintf(hfile,'rny=%d\n', rnym);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxm);
fprintf(hfile,'rdy=%f\n', rdym);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilem);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilem);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
% ditto for high-res
hfile=fopen(['../' lacqheaderfileh],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxh);
fprintf(hfile,'rny=%d\n', rnyh);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxh);
fprintf(hfile,'rdy=%f\n', rdyh);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffileh);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffileh);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
%
% lacq headers for a model limited to the top
% layer (surface)
% required for PP inversion from subsidence
hfile=fopen(['../' Llacqheaderfilel],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', 1);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxl);
fprintf(hfile,'rny=%d\n', rnyl);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxl);
fprintf(hfile,'rdy=%f\n', rdyl);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilel);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilel);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
% ditto for mid-res
hfile=fopen(['../' Llacqheaderfilem],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', 1);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxm);
fprintf(hfile,'rny=%d\n', rnym);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxm);
fprintf(hfile,'rdy=%f\n', rdym);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilem);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilem);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
% ditto for high-res
hfile=fopen(['../' Llacqheaderfileh],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', 1);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxh);
fprintf(hfile,'rny=%d\n', rnyh);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxh);
fprintf(hfile,'rdy=%f\n', rdyh);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffileh);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffileh);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', ksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', kminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', shearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', poissonfile);
%
fclose(hfile);
%
% generate command headers for depth-dependent
% model with 3 reservoir resolution settings
%
hfile=fopen(['../' lacqheaderfileld],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nzz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxl);
fprintf(hfile,'rny=%d\n', rnyl);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxl);
fprintf(hfile,'rdy=%f\n', rdyl);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilel);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilel);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', depthksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', depthkminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', depthshearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', depthpoissonfile);
%
fclose(hfile);
%
% ditto for mid-res
hfile=fopen(['../' lacqheaderfilemd],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nzz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxm);
fprintf(hfile,'rny=%d\n', rnym);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxm);
fprintf(hfile,'rdy=%f\n', rdym);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffilem);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffilem);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', depthksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', depthkminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', depthshearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', depthpoissonfile);
%
fclose(hfile);
%
% ditto for high-res
hfile=fopen(['../' lacqheaderfilehd],'w');
fprintf(hfile,'nx=%d\n', nx);
fprintf(hfile,'ny=%d\n', ny);
fprintf(hfile,'nz=%d\n', nzz);
fprintf(hfile,'x0=%f\n', x0);
fprintf(hfile,'y0=%f\n', y0);
fprintf(hfile,'z0=%f\n', z0);
fprintf(hfile,'dx=%f\n', dx);
fprintf(hfile,'dy=%f\n', dy);
fprintf(hfile,'dz=%f\n', dz);
%
fprintf(hfile,'rnx=%d\n', rnxh);
fprintf(hfile,'rny=%d\n', rnyh);
fprintf(hfile,'rx0=%f\n', rx0);
fprintf(hfile,'ry0=%f\n', ry0);
fprintf(hfile,'rdx=%f\n', rdxh);
fprintf(hfile,'rdy=%f\n', rdyh);
%
fprintf(hfile,'real rzlo(rnx,rny)=%s\n', topsurffileh);
fprintf(hfile,'real rzhi(rnx,rny)=%s\n', bottomsurffileh);
fprintf(hfile,'real ksat(nz,nx,ny)=%s\n', depthksatfile);
fprintf(hfile,'real kmin(nz,nx,ny)=%s\n', depthkminfile);
fprintf(hfile,'real mu(nz,nx,ny)=%s\n', depthshearfile);
fprintf(hfile,'real nu(nz,nx,ny)=%s\n', depthpoissonfile);
%
fclose(hfile);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CREATE PARAMETER FILES
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
hfile=fopen(['../' parmodelsyml],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsyml);
fprintf(hfile,'character* poreout=%s\n',poreoutsyml);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilel);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxl,rnyl,axisymppfilel);
fclose(hfile);
%
hfile=fopen(['../' parmodelsymm],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymm);
fprintf(hfile,'character* poreout=%s\n',poreoutsymm);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilem);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxm,rnym,axisymppfilem);
fclose(hfile);
%
hfile=fopen(['../' parmodelsymh],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymh);
fprintf(hfile,'character* poreout=%s\n',poreoutsymh);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileh);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxh,rnyh,axisymppfileh);
fclose(hfile);
%
% ditto depth-variable
hfile=fopen(['../' parmodelsymld],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymld);
fprintf(hfile,'character* poreout=%s\n',poreoutsymld);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileld);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxl,rnyl,axisymppfilel);
fclose(hfile);
%
hfile=fopen(['../' parmodelsymmd],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymmd);
fprintf(hfile,'character* poreout=%s\n',poreoutsymmd);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilemd);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxm,rnym,axisymppfilem);
fclose(hfile);
%
hfile=fopen(['../' parmodelsymhd],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymhd);
fprintf(hfile,'character* poreout=%s\n',poreoutsymhd);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilehd);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxh,rnyh,axisymppfileh);
fclose(hfile);
%
% now for asymmetric pore=pressure drop...:wa
hfile=fopen(['../' parmodelasyml],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasyml);
fprintf(hfile,'character* poreout=%s\n',poreoutasyml);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilel);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxl,rnyl,asymppfilel);
fclose(hfile);
%
hfile=fopen(['../' parmodelasymm],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymm);
fprintf(hfile,'character* poreout=%s\n',poreoutasymm);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilem);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxm,rnym,asymppfilem);
fclose(hfile);
%
hfile=fopen(['../' parmodelasymh],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymh);
fprintf(hfile,'character* poreout=%s\n',poreoutasymh);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileh);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxh,rnyh,asymppfileh);
fclose(hfile);
%
% ditto depth-variable
hfile=fopen(['../' parmodelasymld],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymld);
fprintf(hfile,'character* poreout=%s\n',poreoutasymld);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileld);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxl,rnyl,asymppfilel);
fclose(hfile);
%
hfile=fopen(['../' parmodelasymmd],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymmd);
fprintf(hfile,'character* poreout=%s\n',poreoutasymmd);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilemd);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxm,rnym,asymppfilem);
fclose(hfile);
%
hfile=fopen(['../' parmodelasymhd],'w');
fprintf(hfile,'model=%d\n',1);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',0);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',1);
fprintf(hfile,'my=%d\n',1);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymhd);
fprintf(hfile,'character* poreout=%s\n',poreoutasymhd);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilehd);
fprintf(hfile,'real pore(%d,%d)=%s\n',rnxh,rnyh,asymppfileh);
fclose(hfile);
%
% create inversion parameter files
hfile=fopen(['../' parinvertsyml],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsyml);
fprintf(hfile,'character* poreout=%s\n',poreoutsyml);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilel);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutsyml);
fclose(hfile);
%
hfile=fopen(['../' parinvertsymm],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymm);
fprintf(hfile,'character* poreout=%s\n',poreoutsymm);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilem);
fprintf(hfile,'nxinit=%d\n',rnxl);
fprintf(hfile,'nyinit=%d\n',rnyl);
fprintf(hfile,'dxinit=%d\n',rdxl);
fprintf(hfile,'dyinit=%d\n',rdyl);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutsyml);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutsymm);
fclose(hfile);
%
hfile=fopen(['../' parinvertsymh],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutsymh);
fprintf(hfile,'character* poreout=%s\n',poreoutsymh);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileh);
fprintf(hfile,'nxinit=%d\n',rnxm);
fprintf(hfile,'nyinit=%d\n',rnym);
fprintf(hfile,'dxinit=%d\n',rdxm);
fprintf(hfile,'dyinit=%d\n',rdym);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutsymm);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'TOL=%20.15g\n',DENSE_TOL);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutsymh);
fclose(hfile);
%
% now for asymmetric inversion
hfile=fopen(['../' parinvertasyml],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasyml);
fprintf(hfile,'character* poreout=%s\n',poreoutasyml);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilel);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutasyml);
fclose(hfile);
%
hfile=fopen(['../' parinvertasymm],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymm);
fprintf(hfile,'character* poreout=%s\n',poreoutasymm);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfilem);
fprintf(hfile,'nxinit=%d\n',rnxl);
fprintf(hfile,'nyinit=%d\n',rnyl);
fprintf(hfile,'dxinit=%d\n',rdxl);
fprintf(hfile,'dyinit=%d\n',rdyl);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutasyml);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutasymm);
fclose(hfile);
%
hfile=fopen(['../' parinvertasymh],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutasymh);
fprintf(hfile,'character* poreout=%s\n',poreoutasymh);
fprintf(hfile,'character* reservoir=%s\n',lacqheaderfileh);
fprintf(hfile,'nxinit=%d\n',rnxm);
fprintf(hfile,'nyinit=%d\n',rnym);
fprintf(hfile,'dxinit=%d\n',rdxm);
fprintf(hfile,'dyinit=%d\n',rdym);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutasymm);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'TOL=%20.15g\n',DENSE_TOL);
fprintf(hfile,'real displacement(%d,%d,%d)=%s\n',3*nz,nx,ny,dispoutasymh);
fclose(hfile);
%
% LACQ subsidence/PP change inversion
hfile=fopen(['../' parinvertlacql],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',0);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutlacql);
fprintf(hfile,'character* poreout=%s\n',poreoutlacql);
fprintf(hfile,'character* reservoir=%s\n',Llacqheaderfilel);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(3,%d,%d)=%s\n',nx,ny,lacqsubsidencefile);
fclose(hfile);
%
hfile=fopen(['../' parinvertlacqm],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutlacqm);
fprintf(hfile,'character* poreout=%s\n',poreoutlacqm);
fprintf(hfile,'character* reservoir=%s\n',Llacqheaderfilem);
fprintf(hfile,'nxinit=%d\n',rnxl);
fprintf(hfile,'nyinit=%d\n',rnyl);
fprintf(hfile,'dxinit=%d\n',rdxl);
fprintf(hfile,'dyinit=%d\n',rdyl);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutlacql);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'real displacement(3,%d,%d)=%s\n',nx,ny,lacqsubsidencefile);
fclose(hfile);
%
hfile=fopen(['../' parinvertlacqh],'w');
fprintf(hfile,'model=%d\n',0);
fprintf(hfile,'init=%d\n',1);
fprintf(hfile,'maxiter=%d\n',MAX_ITER);
fprintf(hfile,'np=%d\n',NOMP);
fprintf(hfile,'mx=%d\n',0);
fprintf(hfile,'my=%d\n',0);
fprintf(hfile,'mz=%d\n',1);
fprintf(hfile,'character* dispout=%s\n',dispoutlacqh);
fprintf(hfile,'character* poreout=%s\n',poreoutlacqh);
fprintf(hfile,'character* reservoir=%s\n',Llacqheaderfileh);
fprintf(hfile,'nxinit=%d\n',rnxm);
fprintf(hfile,'nyinit=%d\n',rnym);
fprintf(hfile,'dxinit=%d\n',rdxm);
fprintf(hfile,'dyinit=%d\n',rdym);
fprintf(hfile,'real poreinit(nxinit,nyinit)=%s\n',poreoutlacqm);
fprintf(hfile,'nx=%d\n',nx);
fprintf(hfile,'ny=%d\n',ny);
fprintf(hfile,'TOL=%20.15g\n',DENSE_TOL);
fprintf(hfile,'real displacement(3,%d,%d)=%s\n',nx,ny,lacqsubsidencefile);
fclose(hfile);
%



