%
% 2012, Musa Maharramov, SEP
% Auxiliary plotting script for SEP147
%
% plot a func of 2 variables stored in an ieee float file
% 'datfilename' as a surface or a contour plot, 
% and save to 'plotfilename'
%
function [ res ] = make2Dsurfplotfile(x0,y0,dx,dy,nx,ny,...
    datfilename, plotfilename,...
    rev,contr,planar,...
    titlelab,xlab,ylab,zlab,tfontsz, xfontsz,yfontsz,zfontsz)
    
% all args starting from 'reverse' are strings and can be empty
% load the data
hfile=fopen(datfilename,'r','ieee-le');
dat=fread(hfile,[nx, ny],'single');
fclose(hfile);
%
% plotting grid
[cx, cy]=meshgrid(linspace(x0,x0+dx*(nx-1),nx),...
    linspace(y0,y0+dy*(nx-1),ny));
h=figure;
    if (~isempty(contr))
      [C, h1]=contour(cx,cy,dat);
      clabel(C,h1);
    else
      surf(cx,cy,dat);
    end
    if (~isempty(titlelab))
      title(titlelab);
      if (~isempty(tfontsz))
        set(get(gca,'Title'),'FontSize',str2double(tfontsz));
      else
        set(get(gca,'Title'),'FontSize',20);
      end
    end
    if (~isempty(titlelab) && ~isempty(tfontsz))
      set(get(gca,'Title'),'FontSize',str2double(tfontsz));
    end
    if (~isempty(xlab))
      xlabel(xlab);
      if (~isempty(xfontsz))
        set(get(gca,'XLabel'),'FontSize',str2double(xfontsz));
      else
        set(get(gca,'XLabel'),'FontSize',14);
      end
    end
    if (~isempty(ylab))
      ylabel(ylab);
      if (~isempty(yfontsz))
        set(get(gca,'YLabel'),'FontSize',str2double(yfontsz));
      else
        set(get(gca,'YLabel'),'FontSize',14);
      end
    end      
    if (~isempty(zlab))
      zlabel(zlab);
      if (~isempty(zfontsz))
        set(get(gca,'Zlabel'),'FontSize',str2double(zfontsz));
      else
        set(get(gca,'Zlabel'),'FontSize',14);
      end
    end
    if (~isempty(rev))
      set(gca,'ZDir','reverse');
    end
    shading interp;
    hc=colorbar;
    if (~isempty(zlab))
      set(get(hc,'Ylabel'),'String',zlab);
      if (~isempty(zfontsz))
        set(get(hc,'Ylabel'),'FontSize',str2double(zfontsz));
      else
        set(get(hc,'Ylabel'),'FontSize',14);
      end
    end
    if (~isempty(planar))
      view(2);
    end
    %Position the plot further to the left and down. 
    % Extend the plot to fill entire paper.
%    set(gcf, 'PaperPosition', [1. -0.25 6.5 5.75]);
    set(gcf, 'PaperSize', [6.5 5.5]); %Keep the same paper size
    % to prevent the Segfault (Matlab bug)
    set(gcf, 'paperpositionmode', 'auto');
    saveas(h,plotfilename);
    res=1;
end
