%
% 2012, Musa Maharramov, SEP
% Auxiliary plotting script for SEP147
%
% plot a selction of a multi-component 3D array (3d vector field) 
% stored in an  ieee float file 'datfilename' as a surface or a contour plot, 
% and save to 'plotfilename'
%
% 'ncomp' is the dimension of the vector field, 'icomp' is the field
% component to plot and 'isection'=1,2,3 is the section toplot
% (1<=>x='ilevel',y<=>2='ilevel',3<=>z='ilevel'
function [ res ] = make3Dsurfplotfile(x0,y0,z0,dx,dy,dz,nx,ny,nz,...
    ncomp,icomp,isection,ilevel,...
    datfilename, plotfilename,...
    rev,contr,planar,...
    titlelab,horlab,vertlab,vallab,tfontsz, horfontsz,vertfontsz,valfontsz)
    
% all args starting from 'reverse' are strings and can be empty
% load the data
hfile=fopen(datfilename,'r','ieee-le');
fulldat=fread(hfile,[ncomp*nz*nx, ny],'single');
fclose(hfile);
%
% plotting grid
if (isection==3)
  [chor, cvert]=meshgrid(linspace(x0,x0+dx*(nx-1),nx),...
      linspace(y0,y0+dy*(nx-1),ny));
  dat=zeros(nx,ny);
  for iy=1:ny
    for ix=1:nx
      dat(ix,iy)=fulldat(ncomp*nz*(ix-1)+ncomp*(ilevel-1)+icomp,iy);
    end
  end  
elseif (isection==2)
  [chor, cvert]=meshgrid(linspace(x0,x0+dx*(nx-1),nx),...
      linspace(z0,z0+dz*(nz-1),nz));
  dat=zeros(nx,nz);
  for iz=1:nz
    for ix=1:nx
      dat(ix,iz)=fulldat(ncomp*nz*(ix-1)+ncomp*(iz-1)+icomp,ilevel);
    end
  end    
else
  [chor, cvert]=meshgrid(linspace(y0,y0+dy*(ny-1),ny),...
      linspace(z0,z0+dz*(nz-1),nz));
  dat=zeros(ny,nz);
  for iz=1:nz
    for iy=1:ny
      dat(iy,iz)=fulldat(ncomp*nz*(ilevel-1)+ncomp*(iz-1)+icomp,iy);
    end
  end      
end
%
h=figure;
    if (~isempty(contr))
      [C, h1]=contour(chor,cvert,dat);
      clabel(C,h1);
    else
      surf(chor,cvert,dat);
    end
    if (~isempty(titlelab))
      title(titlelab);
      if (~isempty(tfontsz))
        set(get(gca,'Title'),'FontSize',str2double(tfontsz));
      else
        set(get(gca,'Title'),'FontSize',20);
      end
    end
    if (~isempty(titlelab) && ~isempty(tfontsz))
      set(get(gca,'Title'),'FontSize',str2double(tfontsz));
    end
    if (~isempty(horlab))
      xlabel(horlab);
      if (~isempty(horfontsz))
        set(get(gca,'XLabel'),'FontSize',str2double(horfontsz));
      else
        set(get(gca,'XLabel'),'FontSize',14);
      end
    end
    if (~isempty(vertlab))
      ylabel(vertlab);
      if (~isempty(vertfontsz))
        set(get(gca,'YLabel'),'FontSize',str2double(vertfontsz));
      else
        set(get(gca,'YLabel'),'FontSize',14);
      end
    end      
    if (~isempty(vallab))
      zlabel(vallab);
      if (~isempty(valfontsz))
        set(get(gca,'Zlabel'),'FontSize',str2double(valfontsz));
      else
        set(get(gca,'Zlabel'),'FontSize',14);
      end
    end
    if (~isempty(rev))
      set(gca,'ZDir','reverse');
    end
    shading interp;
    hc=colorbar;
    if (~isempty(vallab))
      set(get(hc,'Ylabel'),'String',vallab);
      if (~isempty(valfontsz))
        set(get(hc,'Ylabel'),'FontSize',str2double(valfontsz));
      else
        set(get(hc,'Ylabel'),'FontSize',14);
      end
    end
    % check if a planar view is requested
    if (~isempty(planar))
      view(2);
    end
    %Position the plot further to the left and down. 
    % Extend the plot to fill entire paper.
    %set(gcf, 'PaperPosition', [1. -0.25 6.5 5.75]);
    set(gcf, 'PaperSize', [6.5 5.5]); %Keep the same paper size
    % to prevent the Segfault (Matlab bug)    
    set(gcf, 'paperpositionmode', 'auto');
    saveas(h,plotfilename);
    res=1;
end
