!
! Thread-safe error logging module
!
!
! 2012 Stanford Exploration Project
! Musa Maharramov, musa@sep.stanford.edu
!
module error
implicit none
public :: set_error, get_error, warn, warni

! optimisation error & status codes
integer, public, parameter :: LS_MEM_FREE_ER = 1
integer, public, parameter :: LS_MEM_ALLOC_ER = 2
integer, public, parameter :: LS_UNINIT_ER = 3
integer, public, parameter :: LS_SIZE_MISMATCH_ER = 4
integer, public, parameter :: LS_TYPE_MISMATCH_ER = 5
integer, public, parameter :: LS_OK = 1


! IO error and status codes
integer, public, parameter :: IO_UNINIT_ER = 101
integer, public, parameter :: IO_TYPE_MISMATCH_ER  = 102
integer, public, parameter :: IO_BIN_READ_ER  = 103
integer, public, parameter :: IO_NOSUCHMEMBER_ER  = 104
integer, public, parameter :: IO_BIN_OPEN_ER  = 105
integer, public, parameter :: IO_BIN_CLOSE_ER  = 106
integer, public, parameter :: IO_BIN_WRITE_ER  = 107
integer, public, parameter :: IO_HDR_SYNTAX_ER  = 108
integer, public, parameter :: IO_BAD_AXIS_ER = 109
integer, public, parameter :: IO_NOVAL_ER = 110
integer, public, parameter :: IO_UNTYPED_MEMBER_ER=111
integer, public, parameter :: IO_DIM_MISMATCH_ER  = 112
integer, public, parameter :: IO_STR_TOO_LONG_ER  = 113
integer, public, parameter :: IO_HEADER_OPEN_ER  = 114
integer, public, parameter :: IO_HEADER_READ_ER  = 115
integer, public, parameter :: IO_HEADER_WRITE_ER  = 116
integer, public, parameter :: IO_GETCWD_ER  = 117
integer, public, parameter :: IO_OK = 1
!
! func error and status codes
integer, public, parameter :: FUNC_OK = 1
integer, public, parameter :: FUNC_INVPAR_ER = 201
integer, public, parameter :: FUNC_MEM_ALLOC_ER = 202
integer, public, parameter :: FUNC_LAPACK_ER = 203
integer, public, parameter :: FUNC_MEM_FREE_ER = 204

! 'poroelastic_*' error and status codes
integer, public, parameter :: PE_OK = 1
integer, public, parameter :: PE_MEM_ALLOC_ER = 302
integer, public, parameter :: PE_MEM_FREE_ER = 303

integer, private :: ECODE__

contains

function get_error()
integer :: get_error

!$omp critical
  get_error=ECODE__
!$omp end critical

end function get_error

subroutine warn(s)
character(len=*), intent(in) :: s
write (0,'(4096A)') 'WARNING: '//s
end subroutine warn

subroutine warni(s, i)
character(len=*), intent(in) :: s
integer, intent(in) :: i
write (0,*) 'WARNING: ',i
write (0,'(4096A)') s
end subroutine warni

subroutine set_error(icode)
integer :: icode

!$omp critical
  ECODE__=icode
!$omp end critical
  if (icode /=1) write (0,*) 'ERROR:',icode
end subroutine set_error


end module error
