!
! Green's Tensor 
! for displacement response from a
! concentrated dilatation 
! within a reservoir
!
! Abstract class for arbitrary medium
!
! 2012 Musa Maharramov, Stanford University,
!
! See a description of the algorithm in 
! M. Maharramov "Identifying Reservoir 
! Depletion Patterns from Production-Induced
! Deformations", Stanford University,
! 2012 Geomechanics Term Paper
!
!
module green_tensor
use base_oper     ! 
use base_resmodel ! base reservoir model class
implicit none

!
! note that the medium parameters and reservoir
! geometry are defined in the base_reservoir
! member 'res'
type, abstract, public, extends(ls_oper) :: green
contains
  procedure(init_), deferred, pass(this) :: init
  procedure(green_), deferred, pass(this) :: G

! reservoir type
class(base_reservoir), pointer :: res
! flags indicating which displacement
! components to model (x,y,z)
  logical :: mx,my,mz
end type  green

abstract interface
  subroutine init_(this,res,mx,my,mz)
  import green, base_reservoir
  class(green), intent(inout) :: this
  class(base_reservoir),intent(inout),pointer :: res
  logical, intent(in) :: mx, my, mz
  end subroutine init_

! compute 3D displacement d(k,x,y,z,rx,ry,rz)
! at (x,y,z) along axis 'k; due to a concentrated
! dilatation at (rx,ry,rz) for the reservoir
! model this%res
  subroutine green_(this,rz0,rdz,rnz,d)
  import green, base_reservoir
  class(green), intent(inout) :: this
! z grid where dilatation is applied
  real, intent(in) :: rdz
! allow reservoir z grid to have variable orig
  real, intent(inout), dimension(:,:) :: rz0
  integer, intent(in) :: rnz
! displacement(1:3,z,x,y,rz,rx,ry)
  real,intent(inout),dimension(:,:,:,:,:,:,:) :: d
  end subroutine green_


end interface

end module green_tensor



