!
! Base reservoir model type
!
! 2012 Musa Maharramov, Stanford University
!
! Version 0.2 use type(persistent)
!
module poroelastic_resmodel
use base_resmodel
implicit none

!
! base reservoir type
! modelled as a 3D domain between
! two surfaces
type, public, extends(base_reservoir) :: pe_reservoir
! medium parameters
real, dimension(:,:,:), pointer :: Ksat,Kmin,mu,nu
contains
      procedure :: load => lpres
      procedure :: store => spres
end type  pe_reservoir


contains

! load from header
subroutine lpres(this,header)
class(pe_reservoir), intent(inout) :: this
class(header_type), intent(inout) :: header
! invoke parent loader
  call this%base_reservoir%load(header)
  allocate(this%Ksat(this%nz,this%nx,this%ny))
  allocate(this%Kmin(this%nz,this%nx,this%ny))
  allocate(this%mu(this%nz,this%nx,this%ny))
  allocate(this%nu(this%nz,this%nx,this%ny))
  call header%load(this%Ksat,'ksat')
  call header%load(this%Kmin,'kmin')
  call header%load(this%mu,'mu')
  call header%load(this%nu,'nu')
end subroutine lpres

! store from header
subroutine spres(this,header)
class(pe_reservoir), intent(inout) :: this
class(header_type), intent(inout) :: header
! invoke parent writer
  call this%base_reservoir%store(header)
  call header%store(this%Ksat,'ksat')
  call header%store(this%Kmin,'kmin')
  call header%store(this%mu,'mu')
  call header%store(this%nu,'nu')
end subroutine spres

end module poroelastic_resmodel

