!
! Base reservoir model type
!
! 2012 Musa Maharramov, Stanford University
!
! Version 0.2 use type(persistent)
!
module base_resmodel
use io
implicit none


!
! base reservoir type
! modelled as a 3D domain between
! two surfaces
type, public, extends(persistent) :: base_reservoir
! medium grid
integer :: nx,ny,nz
real :: x0,y0,z0,dx,dy,dz

! 2D reservoir grid
! note the z axis points downward
integer :: rnx,rny
real :: rx0,ry0,rdx,rdy
! reservoir bounding surfaces (low/high)
real, dimension(:,:), pointer :: rzlo
real, dimension(:,:), pointer :: rzhi
contains
      procedure :: load => lres
      procedure :: store => sres
end type  base_reservoir

contains

! load from header
subroutine lres(this,header)
class(base_reservoir), intent(inout) :: this
class(header_type), intent(inout) :: header
  call header%load(this%nx,'nx')
  call header%load(this%ny,'ny')
  call header%load(this%nz,'nz')
  call header%load(this%rnx,'rnx')
  call header%load(this%rny,'rny')
  call header%load(this%dx,'dx')
  call header%load(this%dy,'dy')
  call header%load(this%dz,'dz')
  call header%load(this%x0,'x0')
  call header%load(this%y0,'y0')
  call header%load(this%z0,'z0')
  call header%load(this%rdx,'rdx')
  call header%load(this%rdy,'rdy')
  call header%load(this%rx0,'rx0')
  call header%load(this%ry0,'ry0')
  allocate(this%rzlo(this%rnx,this%rny))
  allocate(this%rzhi(this%rnx,this%rny))
  call header%load(this%rzlo,'rzlo')
  call header%load(this%rzhi,'rzhi')
end subroutine lres

! store to header
subroutine sres(this,header)
class(base_reservoir), intent(inout) :: this
class(header_type), intent(inout) :: header
  call header%store(this%nx,'nx')
  call header%store(this%ny,'ny')
  call header%store(this%nz,'nz')
  call header%store(this%rnx,'rnx')
  call header%store(this%rny,'rny')
  call header%store(this%dx,'dx')
  call header%store(this%dy,'dy')
  call header%store(this%dz,'dz')
  call header%store(this%x0,'x0')
  call header%store(this%y0,'y0')
  call header%store(this%z0,'z0')
  call header%store(this%rdx,'rdx')
  call header%store(this%rdy,'rdy')
  call header%store(this%rx0,'rx0')
  call header%store(this%ry0,'ry0')
  call header%store(this%rzlo,'rzlo')
  call header%store(this%rzhi,'rzhi')
end subroutine sres

end module base_resmodel

