!
! Abstract vector class for the Generic Least 
! Squares Solver abstract interface library.

! 2012 Stanford Exploration Project
! Musa Maharramov, musa@sep.stanford.edu
!
module base_vector 
implicit none

! abstract vector type -- i.e. vectors m or d in (*)
type, abstract :: ls_vector
contains
  procedure(in_), deferred, pass(this) :: inobject
  procedure(ina_), deferred, pass(this) :: inarray
  procedure(out_), deferred, pass(this) :: outobject
  procedure(outa_), deferred, pass(this) :: outarray
  procedure(dot_), deferred, pass(this) :: dot
  procedure(lc_), deferred, pass(this) :: lc
  procedure(cwmult_), deferred, pass(this) :: cwmult
  procedure(spawn_), deferred, pass(this) :: spawn
  procedure(zero_), deferred, pass(this) :: zero
  generic, public :: in => inobject, inarray
  generic, public :: out => outobject, outarray
end type ls_vector

! defined assignment operations
interface assignment(=)
 module procedure vector_to_vector_assign, vector_to_array_assign, array_to_vector_assign
end interface
!
!  
abstract interface

subroutine in_(this, src)
import :: ls_vector
class(ls_vector), intent(inout) :: this
class(ls_vector), intent(in) :: src
end subroutine in_

subroutine ina_(this, vec, cnt)
import :: ls_vector
class(ls_vector), intent(inout) :: this
real, dimension(:), intent(in) :: vec
integer, intent(in) :: cnt
end subroutine ina_

subroutine out_(this, dest) 
import :: ls_vector
class(ls_vector), intent(in) :: this
class(ls_vector), intent(inout) :: dest
end subroutine out_

subroutine outa_(this, vec, cnt)
import :: ls_vector
class(ls_vector), intent(in) :: this
real, dimension(:), intent(inout) :: vec
integer, intent(in) :: cnt
end subroutine outa_

! dot product prototype
function dot_(this, vec)
import :: ls_vector
real :: dot_
class(ls_vector), intent(inout) :: this
class(ls_vector), intent(in) :: vec
end function dot_

! spawn a new object
subroutine spawn_(this, res)
import :: ls_vector
class(ls_vector), intent(inout) :: this
class(ls_vector), intent(out), pointer :: res
end subroutine spawn_

! zero an abstract vector
subroutine zero_(this)
import :: ls_vector
class(ls_vector), intent(inout) :: this
end subroutine zero_


! linear combination product prototype
! this = alpha*u + beta*v
subroutine lc_(this, u, v, alpha, beta)
import :: ls_vector
class(ls_vector), intent(inout) :: this
class(ls_vector), intent(in) :: u
class(ls_vector), intent(in), optional :: v
real, intent(in), optional :: alpha, beta
end subroutine lc_
!
! component-wise multiplication
subroutine cwmult_(this, u, v)
import :: ls_vector
class(ls_vector), intent(inout) :: this
class(ls_vector), intent(in) :: u,v
end subroutine cwmult_
!
end interface

contains

! assignment of a vector object to vector
subroutine vector_to_vector_assign(left,right)
class(ls_vector), intent(inout) :: left
class(ls_vector), intent(in) :: right
  call left%in(right);
  return
end subroutine vector_to_vector_assign

! assignment of a vector cl;ass to vector
subroutine vector_to_array_assign(left,right)
real, dimension(:), intent(inout) :: left
class(ls_vector), intent(in) :: right
  call right%out(left,size(left));
  return
end subroutine vector_to_array_assign

! assignment of an array to vector
subroutine array_to_vector_assign(left,right)
class(ls_vector), intent(inout) :: left
real, dimension(:), intent(in) :: right 
  call left%in(right,size(right));
  return
end subroutine array_to_vector_assign


end module base_vector
