%
% Synthetic Reservoir model and pore pressure
% plot generator for outpuits of 'zpemodel.x' 0.5
%
% 2012 Musa Maharramov
% Stanford Exploration Project
% Stanford University
%
clc
%
% model parameters
nx=101;ny=101;nz=20;
x0=-10.;y0=-10.;z0=0;
dx=-2.*x0/(nx-1);dy=-2.*y0/(ny-1);dz=.1;

ize=1;ucomp=3;
%
[ccx, ccy]=meshgrid(linspace(x0,x0+(nx-1)*dx,nx),...
            linspace(y0,y0+(ny-1)*dy,ny));
%
fname='dispout_from_symmetric.bin';
hfile=fopen(fname,'r','ieee-le');
d3d=zeros(3*nz*nx,ny);
d3d=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
fname='dispout_from_symmetric_hires.bin';
hfile=fopen(fname,'r','ieee-le');
d3dh=zeros(3*nz*nx,ny);
d3dh=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
%
dp=zeros(nx,ny);dph=dp;
% extract into 'dp' the z component only
for iy=1:ny
  for ix=1:nx    
    dp(ix,iy)=d3d(3*(nz*(ix-1)+ize)+ucomp,iy);
  dph(ix,iy)=d3dh(3*(nz*(ix-1)+ize)+ucomp,iy);
  end
end
%
figure
    surf(ccx, ccy, dp);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Axisymmetric PP Drop' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dp);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Axisymmetric PP Drop' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    surf(ccx, ccy, dph);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Axisymmetric PP Drop, high res' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dph);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Axisymmetric PP Drop, high res');
    shading interp;
    colorbar

    %
fname='dispout_from_asymmetric.bin';
hfile=fopen(fname,'r','ieee-le');
d3d=zeros(3*nz*nx,ny);
d3d=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
fname='dispout_from_asymmetric_hires.bin';
hfile=fopen(fname,'r','ieee-le');
d3dh=zeros(3*nz*nx,ny);
d3dh=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
%
dp=zeros(nx,ny);dph=dp;
% extract into 'dp' the z component only
for iy=1:ny
  for ix=1:nx    
    dp(ix,iy)=d3d(3*(nz*(ix-1)+ize)+ucomp,iy);
  dph(ix,iy)=d3dh(3*(nz*(ix-1)+ize)+ucomp,iy);
  end
end
%
figure
    surf(ccx, ccy, dp);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Asymmetric PP Drop' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dp);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Asymmetric PP Drop' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    surf(ccx, ccy, dph);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Asymmetric PP Drop, high res' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dph);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(gca,'ZDir','reverse');
    title(['Vert Displacement for Asymmetric PP Drop, high res' ' iz=' num2str(ize) ' component= ' num2str(ucomp) ]);
    shading interp;
    colorbar

    
    