%
% Synthetic Reservoir model and pore pressure
% plot generator for outpuits of 'pemodel.x' 0.2
%
% 2012 Musa Maharramov
% Stanford Exploration Project
% Stanford University
%
clc
%
% reservoir grid
rnx=11;rny=11;
% resrevoir radius
radius=8.;
rx0=-radius;ry0=-radius;
rdx=2.*radius/(rnx-1);rdy=2.*radius/(rny-1);
[cx, cy]=meshgrid(linspace(rx0,rx0+rdx*(rnx-1),rnx), linspace(ry0,ry0+rdy*(rny-1),rny));
%
% high res reservoir grid
rnxh=81;rnyh=81;
% resrevoir radius
rdxh=2.*radius/(rnxh-1);rdyh=2.*radius/(rnyh-1);
[cxh, cyh]=meshgrid(linspace(rx0,rx0+rdxh*(rnxh-1),rnxh), linspace(ry0,ry0+rdyh*(rnyh-1),rnyh));
% inverted pore pressure (for axisymmetric case)
fname='porout_from_symmetric_5iter.bin';
hfile=fopen(fname,'r','ieee-le');
pp=zeros(rnx,rny);
pp=fread(hfile,[rnx, rny],'single');
fclose(hfile);
%
fname='porout_from_symmetric_5iter.bin';
hfile=fopen(fname,'r','ieee-le');
pp5iter=zeros(rnx,rny);
pp5iter=fread(hfile,[rnx, rny],'single');
fclose(hfile);
%
fname='porout_from_symmetric_5iter_hires.bin';
hfile=fopen(fname,'r','ieee-le');
pp5iterh=zeros(rnxh,rnyh);
pp5iterh=fread(hfile,[rnxh, rnyh],'single');
fclose(hfile);
%
h=figure
    surf(cx,cy,pp);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);
    shading interp;
    colorbar;
    saveas(h,'INVAXISYMPP.pdf');

figure
    [C,h]=contour(cx,cy,pp);
    clabel(C,h);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);
    shading interp;
    colorbar
%
figure
    surf(cx,cy,pp5iter);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa, 5 iters');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    shading interp;
    colorbar
figure
    [C,h]=contour(cx,cy,pp5iter);
    clabel(C,h);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa, 5 iters');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa')
    shading interp;
    colorbar
%
figure
    surf(cxh,cyh,pp5iterh);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa, 5 iters, high res');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    shading interp;
    colorbar
figure
    [C,h]=contour(cxh,cyh,pp5iterh);
    clabel(C,h);
    title('Inverted Axisymmetric Pore-Pressure Drop MPa, 5 iters, high res');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);   
    shading interp;
    colorbar
%    
% model parameters
nx=101;ny=101;nz=5;
x0=-10.;y0=-10.;z0=0;
dx=-2.*x0/(nx-1);dy=-2.*y0/(ny-1);dz=.3;
%
[ccx, ccy]=meshgrid(linspace(x0,x0+(nx-1)*dx,nx),...
            linspace(y0,y0+(ny-1)*dy,ny));
%
fname='dispout_from_symmetric.bin';
hfile=fopen(fname,'r','ieee-le');
d3d=zeros(3*nz*nx,ny);
d3d=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
fname='dispout_from_symmetric_hires.bin';
hfile=fopen(fname,'r','ieee-le');
d3dh=zeros(3*nz*nx,ny);
d3dh=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
%
dp=zeros(nx,ny);dph=dp;
% extract into 'dp' the z component only
% depth level to extract
ize=1;
for iy=1:ny
  for ix=1:nx    
    dp(ix,iy)=d3d(3*(nz*(ix-1)+ize-1)+3,iy);
    dph(ix,iy)=d3dh(3*(nz*(ix-1)+ize-1)+3,iy);
  end
end
%
figure
    surf(ccx, ccy, dp);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Axisymmetric PP Drop');
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dp);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Axisymmetric PP Drop');
    shading interp;
    colorbar
%
figure
    surf(ccx, ccy, dph);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Axisymmetric PP Drop, high res');
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dph);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Axisymmetric PP Drop, high res');
    shading interp;
    colorbar
%
%
%
%
%
%
% ditto for asymmetric
fname='porout_from_asymmetric_5iter.bin';
hfile=fopen(fname,'r','ieee-le');
pp=zeros(rnx,rny);
pp=fread(hfile,[rnx, rny],'single');
fclose(hfile);
%
fname='porout_from_asymmetric_5iter.bin';
hfile=fopen(fname,'r','ieee-le');
pp5iter=zeros(rnx,rny);
pp5iter=fread(hfile,[rnx, rny],'single');
fclose(hfile);
%
fname='porout_from_asymmetric_5iter_hires.bin';
hfile=fopen(fname,'r','ieee-le');
pp5iterh=zeros(rnxh,rnyh);
pp5iterh=fread(hfile,[rnxh, rnyh],'single');
fclose(hfile);
%
figure
    surf(cx,cy,pp);
    title('Inverted Asymmetric Pore-Pressure Drop MPa');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);
    shading interp;
    colorbar
figure
    [C,h]=contour(cx,cy,pp);
    clabel(C,h);
    title('Inverted Asymmetric Pore-Pressure Drop MPa');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);
    shading interp;
    colorbar
%
figure
    surf(cx,cy,pp5iter);
    title('Inverted Asymmetric Pore-Pressure Drop MPa, 5 iters');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    shading interp;
    colorbar
figure
    [C,h]=contour(cx,cy,pp5iter);
    clabel(C,h);
    title('Inverted Asymmetric Pore-Pressure Drop MPa, 5 iters');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa')
    shading interp;
    colorbar
%
figure
    surf(cxh,cyh,pp5iterh);
    title('Inverted Asymmetric Pore-Pressure Drop MPa, 5 iters, high res');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    shading interp;
    colorbar
figure
    [C,h]=contour(cxh,cyh,pp5iterh);
    clabel(C,h);
    title('Inverted Asymmetric Pore-Pressure Drop MPa, 5 iters, high res');
    xlabel('x - km');
    ylabel('y - km');
    zlabel('MPa');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);   
    shading interp;
    colorbar
%    
% model parameters
nx=101;ny=101;nz=5;
x0=-10.;y0=-10.;z0=0;
dx=-2.*x0/(nx-1);dy=-2.*y0/(ny-1);dz=.3;
%
[ccx, ccy]=meshgrid(linspace(x0,x0+(nx-1)*dx,nx),...
            linspace(y0,y0+(ny-1)*dy,ny));
%
fname='dispout_from_asymmetric.bin';
hfile=fopen(fname,'r','ieee-le');
d3d=zeros(3*nz*nx,ny);
d3d=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
fname='dispout_from_asymmetric_hires.bin';
hfile=fopen(fname,'r','ieee-le');
d3dh=zeros(3*nz*nx,ny);
d3dh=fread(hfile,[3*nz*nx, ny],'single');
fclose(hfile);
%
dp=zeros(nx,ny);dph=dp;
% extract into 'dp' the z component only
% depth level to extract
ize=1;
for iy=1:ny
  for ix=1:nx    
    dp(ix,iy)=d3d(3*(nz*(ix-1)+ize-1)+3,iy);
    dph(ix,iy)=d3dh(3*(nz*(ix-1)+ize-1)+3,iy);
  end
end
%
figure
    surf(ccx, ccy, dp);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Asymmetric PP Drop');
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dp);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Asymmetric PP Drop');
    shading interp;
    colorbar
%
figure
    surf(ccx, ccy, dph);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Asymmetric PP Drop, high res');
    shading interp;
    colorbar
%
figure
    [C,h]=contour(ccx, ccy, dph);
    clabel(C,h);
    xlabel('x - km');
    ylabel('y - km');
    zlabel('m');
    set(get(gca,'XLabel'),'FontSize',14);
    set(get(gca,'YLabel'),'FontSize',14);
    set(get(gca,'ZLabel'),'FontSize',14);    
    set(gca,'ZDir','reverse');
    title('Vert Displacement for Asymmetric PP Drop, high res');
    shading interp;
    colorbar

exit;
