! LibLs driver programme
!
! Generic Least Squares Solver abstract interface library
! and a sample solver implementatios for solving
! overdetermined Linear Least Squares problem.
!
! Sample driver programme.
!
! IMPORTANT: In a production solver, greater care 
! should be taken of the potential loss of
! orthogonality Krylov space bases;
!
! ls_cgnr class is intended just as a sample 
! demonstration of how to extend ls_solver
!
program LLS_Driver
!
!
use simple_vector
use base_oper
use cgnr
use driver_defs

implicit none

type(vector) :: m,d
class(ls_vector),pointer :: pd

type(ls_cgnr) :: solver

real, dimension(1:N) :: m0, rhs, x0
real :: rnorm2, rnormprev

class(ls_oper), pointer :: op

integer :: i, j

allocate(my_oper::op)

print *,'Sample LibLs Driver'

do i = 1,N
  m0(i)=i
  do j=1, N
!   playing with various matrices
    call random_number(mtrx(j,i))
!    mtrx(j,i)=abs(i-j)+1
    mtrx(j,i)=mtrx(j,i)*(abs(i+j))+i+j
!     if (i==j) then
!       mtrx(i,j)=1
!     else
!       mtrx(i,j)=0
!     end if
  end do
end do

rhs=0

do i = 1,N
  do j=1, N
    rhs(j)=rhs(j)+mtrx(j,i)*m0(i)
  end do
end do
!
! now rhs(:) and x0(:) contain the right-hand 
! side and initial approx
!
x0=0
d=rhs; m=x0

call solver%init(op, m, d,.true.)
rnorm2=1e+10;
do 
  print *,'==================================='
  print *,'ITERATION', solver%get_iter()
  call solver%step()
  rnormprev=rnorm2
  x0=solver%m
  print *, '====>',x0
! a termination condition
!
! CG should converge in no more than N steps
! but because or sample implementation may suffer
! from Krylov basis non-orthogonality, 
! allow it to run a bit longer
  if (solver%get_iter()>10*N) exit
end do

x0=solver%m;
m0=m0-x0
print *, 'error of the result:'
print *, m0
rhs = solver%r
print *, 'res=',rhs


end program LLS_Driver
